# Resources

## A. Within the plugin's interface

- Tooltips
  : We provide tooltips for terms throughout the plugin, simply hover over the question-mark icon next to any term to read a brief description

    ```{image} images/tooltip.png
    :width: 90%
    ```

- `Help` menu dropdown:

  : :::{figure} images/help.png
  ::: 
  
    - **User Guide**: links to this online [User Guide](http://githubpage.io), which we'll strive to keep up-to-date



    - **GitHub**: links to the [source code](https://github.com/AllenCell/allencell-segmenter-ml) of the plugin and where you can submit technical issues/bugs



    - **Forum**: links to [Image.sc forum](https://forum.image.sc/tag/segmenter), where you can find Segmenter-related topics. Feel free to ask any questions about the plugin - our team actively monitors this forum section.



    - **Website**: links to the [Segmenter tool webpage](https://allencell.org/segmenter), which includes an overview of the original Python toolkit, the **Segmenter - Classic** tool, and other relevant information



    - **Experiment home**: click to view the current location of your home directory, with the option to change it to a different location if needed



    - **Download models**: click to download our {ref}`pre-trained models<Pre-trained models>` that are ready for use, featuring MegaSeg, a structure-agnostic high-quality segmentation model.


______________________________________________________________________

## B. Helpful links

- GitHub repository: [allencell-segmenter-ml](https://github.com/AllenCell/allencell-segmenter-ml)

- Submit a GitHub issue, request a new feature, or general feedback: [GitHub issues](https://github.com/AllenCell/allencell-segmenter-ml/issues/new/choose)

- Check {ref}`Frequently Asked Questions`

- Ask a question: [Image.sc forum](https://forum.image.sc/tag/segmenter)

- Overview webpage: [Allen Cell & Structure Segmenter](https://allencell.org/segmenter)

______________________________________________________________________
